@@ -1,4 +1,4 @@
-/* $Id: proclist.h,v 1.31 2005/06/07 09:54:43 bdejean Exp $ */
+/* $Id: proclist.h 2482 2006-04-18 20:17:25Z gpoo $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -56,10 +56,10 @@ typedef struct _glibtop_proclist	glibtop_proclist;
 
 struct _glibtop_proclist
 {
-	guint64	flags,
-		number,			/* GLIBTOP_PROCLIST_NUMBER	*/
-		total,			/* GLIBTOP_PROCLIST_TOTAL	*/
-		size;			/* GLIBTOP_PROCLIST_SIZE	*/
+	guint64	flags;
+	guint64 number;			/* GLIBTOP_PROCLIST_NUMBER	*/
+	guint64 total;			/* GLIBTOP_PROCLIST_TOTAL	*/
+	guint64 size;			/* GLIBTOP_PROCLIST_SIZE	*/
 };
 
 unsigned *
