@@ -1,4 +1,4 @@
-/* $Id: glibtop_suid.h,v 1.2 2003/10/19 16:54:39 carlos Exp $ */
+/* $Id: glibtop_suid.h 1862 2003-10-20 15:20:16Z hadess $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -24,7 +24,7 @@
 #ifndef __GLIBTOP_SUID_H__
 #define __GLIBTOP_SUID_H__
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #if _IN_LIBGTOP
 #include <sys/param.h>
@@ -47,6 +47,6 @@ glibtop_open_p (glibtop *server, const char *program_name,
 		const unsigned long features,
 		const unsigned flags);
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
