@@ -1,4 +1,4 @@
-/* $Id: procmap.c,v 1.21 2005/12/12 13:37:15 bdejean Exp $ */
+/* $Id: procmap.c 2546 2007-01-14 18:09:56Z bdejean $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -38,9 +38,7 @@
 #define SMAPS_FILE "/proc/%u/smaps"
 
 
-#define PROC_MAPS_FORMAT ((sizeof(void*) == 8) \
-? "%16lx-%16lx %4c %16lx %02hx:%02hx %lu%*[ ]%[^\n]\n" \
-: "%08lx-%08lx %4c %08lx %02hx:%02hx %lu%*[ ]%[^\n]\n")
+#define PROC_MAPS_FORMAT "%16llx-%16llx %4c %16llx %02hx:%02hx %llu%*[ ]%n"
 
 
 static const unsigned long _glibtop_sysdeps_proc_map =
@@ -133,12 +131,17 @@ glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 					       100);
 	FILE *maps;
 	const char *filename;
+	gboolean has_smaps;
+	char *line = NULL;
+	size_t line_size = 0;
 
 	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_MAP, 0);
 
 	memset (buf, 0, sizeof (glibtop_proc_map));
 
-	if (server->os_version_code >= LINUX_VERSION_CODE(2, 6, 0))
+	has_smaps = server->os_version_code >= LINUX_VERSION_CODE(2, 6, 14);
+
+	if (has_smaps)
 		filename = SMAPS_FILE;
 	else
 		filename = MAPS_FILE;
@@ -151,32 +154,28 @@ glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 
 	while(TRUE)
 	{
-		char line[1024];
-
 		unsigned long perm = 0;
-		int rv;
 		guint len;
+		int line_end;
 
 		unsigned short dev_major, dev_minor;
-		unsigned long start, end, offset, inode;
+		guint64 start, end, offset, inode;
 		char flags[4];
-		char filename [GLIBTOP_MAP_FILENAME_LEN+1];
+		char *filename;
 
 		glibtop_map_entry *entry;
 
-		if (!fgets(line, sizeof line, maps))
+		if (getline(&line, &line_size, maps) == -1)
 			break;
 
 		/* 8 arguments */
-		rv = sscanf(line, PROC_MAPS_FORMAT,
-			    &start, &end, flags, &offset,
-			    &dev_major, &dev_minor, &inode, filename);
+		if (sscanf(line, PROC_MAPS_FORMAT,
+			   &start, &end, flags, &offset,
+			   &dev_major, &dev_minor, &inode, &line_end) != 7)
+			break;
 
-		if(rv == EOF || rv < 7)
-		  break;
-
-		if(rv == 7) /* no filename */
-		  filename[0] = '\0';
+		filename = line + line_end;
+		g_strstrip(filename);
 
 		/* Compute access permissions. */
 
@@ -203,19 +202,20 @@ glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 		entry = &g_array_index(entry_list, glibtop_map_entry, len);
 
 		entry->flags = _glibtop_sysdeps_map_entry;
-		entry->start = (guint64) start;
-		entry->end = (guint64) end;
-		entry->offset = (guint64) offset;
-		entry->perm = (guint64) perm;
-		entry->device = (guint64) MKDEV(dev_major, dev_minor);
-		entry->inode = (guint64) inode;
+		entry->start = start;
+		entry->end = end;
+		entry->offset = offset;
+		entry->perm = perm;
+		entry->device = MKDEV(dev_major, dev_minor);
+		entry->inode = inode;
 		g_strlcpy(entry->filename, filename, sizeof entry->filename);
 
-		if (server->os_version_code >= LINUX_VERSION_CODE(2, 6, 0))
+		if (has_smaps)
 			add_smaps(server, maps, entry);
 
 	}
 
+	free(line);
 	fclose (maps);
 
 	buf->flags = _glibtop_sysdeps_proc_map;
